@@ -7,7 +7,7 @@ import subprocess
 import time
 import shlex
 import io
-
+from shutil import rmtree
 
 @click.command()
 @click.option('--foldername', '-f',  default='server', help='Name of the folder for the new flask react server')
@@ -36,8 +36,11 @@ def main(foldername, apipath, norun, port, host):
     except OSError as e:
         if e.errno != errno.EEXIST:
             continueBool = click.confirm('Same folder exists, are you sure you want to delete it?', abort=True)
+            rmdir(new_path_server)
 
-
+    if continueBool:
+        rmtree(new_path_server)
+        makedirs(new_path_server)
 
     server_app = join(new_path_server, 'app.py')
     reqs = join(new_path_server, 'requirements.txt')
@@ -137,7 +140,7 @@ __pycache__/
     click.echo('')
     complete = False
     try:
-        pythonUsed = environ['_']
+        pythonUsed = click.prompt('What is your python command (e.g., python python3)', type=str)
         res1 = ''
         res2 = ''
         try:
